@@ -3,4 +3,8 @@
 #endif
 #include "stubs.h"
 
+#ifdef __SUNPRO_C
+#pragma weak serverClient
+#endif
+
 weak void *serverClient = 0;
